@@ -1,3 +1,4 @@
+import pytest
 from sanic import Sanic
 from sanic.response import empty, text
 
@@ -85,3 +86,20 @@ def test_auto_head_with_vhosts(app: Sanic, get_docs):
 
     schema = get_docs()
     assert "get" in schema["paths"]["/foo"]
+
+
+# This test also appears in Core Sanic tests but is added here as well
+# because of: https://github.com/sanic-org/sanic-ext/issues/148
+@pytest.mark.parametrize("unquote", [True, False, None])
+def test_unquote_add_route(app, unquote):
+    async def handler1(_, foo):
+        return text(foo)
+
+    app.add_route(handler1, "/<foo>", unquote=unquote)
+    value = "啊" if unquote else r"%E5%95%8A"
+
+    _, response = app.test_client.get("/啊")
+    assert response.text == value
+
+    _, response = app.test_client.get(r"/%E5%95%8A")
+    assert response.text == value
